#######################
Referenced Publications
#######################



.. _helmstetter-2006:

Helmstetter, A., Y. Y. Kagan, and D. D. Jackson (2006). Comparison of short-term and time-independent earthquake
forecast models for southern California, *Bulletin of the Seismological Society of America* **96** 90-106.

.. _rhoades-2011:

Rhoades, D. A., D. Schorlemmer, M. C. Gerstenberger, A. Christophersen, J. D. Zechar, and M. Imoto (2011). Efficient
testing of earthquake forecasting models, *Acta Geophys* **59** 728-747.

.. _savran-2020:

Savran, W., M. J. Werner, W. Marzocchi, D. Rhoades, D. D. Jackson, K. R. Milner, E. H. Field, and A. J. Michael (2020).
Pseudoprospective evaluation of UCERF3-ETAS forecasts during the 2019 Ridgecrest Sequence,
*Bulletin of the Seismological Society of America*.

.. _schorlemmer-2007:

Schorlemmer, D., M. Gerstenberger, S. Wiemer, D. D. Jackson, and D. A. Rhoades (2007). Earthquake likelihood model
testing, *Seismological Research Letters* **78** 17-29.

.. _werner-2011:

Werner, M. J., A. Helmstetter, D. D. Jackson, and Y. Y. Kagan (2011). High-Resolution Long-Term and Short-Term
Earthquake Forecasts for California, *Bulletin of the Seismological Society of America* **101** 1630-1648.

.. _zechar-2010:

Zechar, J. D., M. C. Gerstenberger, and D. A. Rhoades (2010). Likelihood-Based Tests for Evaluating Space-Rate-Magnitude
Earthquake Forecasts, *Bulletin of the Seismological Society of America* **100** 1184-1195.






